@@ -40,6 +40,7 @@ type Feed struct {
 	Crawler                     bool      `json:"crawler"`
 	BlocklistRules              string    `json:"blocklist_rules"`
 	KeeplistRules               string    `json:"keeplist_rules"`
+	UrlRewriteRules             string    `json:"urlrewrite_rules"`
 	UserAgent                   string    `json:"user_agent"`
 	Cookie                      string    `json:"cookie"`
 	Username                    string    `json:"username"`
@@ -141,6 +142,7 @@ type FeedCreationRequest struct {
 	BlocklistRules              string `json:"blocklist_rules"`
 	KeeplistRules               string `json:"keeplist_rules"`
 	HideGlobally                bool   `json:"hide_globally"`
+	UrlRewriteRules             string `json:"urlrewrite_rules"`
 }
 
 // FeedModificationRequest represents the request to update a feed.
@@ -152,6 +154,7 @@ type FeedModificationRequest struct {
 	RewriteRules                *string `json:"rewrite_rules"`
 	BlocklistRules              *string `json:"blocklist_rules"`
 	KeeplistRules               *string `json:"keeplist_rules"`
+	UrlRewriteRules             *string `json:"urlrewrite_rules"`
 	Crawler                     *bool   `json:"crawler"`
 	UserAgent                   *string `json:"user_agent"`
 	Cookie                      *string `json:"cookie"`
@@ -191,6 +194,10 @@ func (f *FeedModificationRequest) Patch(feed *Feed) {
 		feed.KeeplistRules = *f.KeeplistRules
 	}
 
+	if f.UrlRewriteRules != nil {
+		feed.UrlRewriteRules = *f.UrlRewriteRules
+	}
+
 	if f.BlocklistRules != nil {
 		feed.BlocklistRules = *f.BlocklistRules
 	}
