@@ -15,6 +15,36 @@ func TestValidInput(t *testing.T) {
 	}
 }
 
+func TestImgWithWidthAndHeightAttribute(t *testing.T) {
+	input := `<img src="https://example.org/image.png" width="10" height="20">`
+	expected := `<img src="https://example.org/image.png" width="10" height="20" loading="lazy">`
+	output := Sanitize("http://example.org/", input)
+
+	if output != expected {
+		t.Errorf(`Wrong output: %s`, output)
+	}
+}
+
+func TestImgWithWidthAndHeightAttributeLargerThanMinifluxLayout(t *testing.T) {
+	input := `<img src="https://example.org/image.png" width="1200" height="675">`
+	expected := `<img src="https://example.org/image.png" loading="lazy">`
+	output := Sanitize("http://example.org/", input)
+
+	if output != expected {
+		t.Errorf(`Wrong output: %s`, output)
+	}
+}
+
+func TestImgWithIncorrectWidthAndHeightAttribute(t *testing.T) {
+	input := `<img src="https://example.org/image.png" width="10px" height="20px">`
+	expected := `<img src="https://example.org/image.png" loading="lazy">`
+	output := Sanitize("http://example.org/", input)
+
+	if output != expected {
+		t.Errorf(`Wrong output: %s`, output)
+	}
+}
+
 func TestImgWithTextDataURL(t *testing.T) {
 	input := `<img src="data:text/plain;base64,SGVsbG8sIFdvcmxkIQ==" alt="Example">`
 	expected := ``
@@ -45,16 +75,6 @@ func TestImgWithSrcset(t *testing.T) {
 	}
 }
 
-func TestImgWithSrcsetAndDataURL(t *testing.T) {
-	input := `<img srcset="data:image/gif;base64,test" src="http://example.org/example-320w.jpg" alt="Example">`
-	expected := `<img srcset="data:image/gif;base64,test" src="http://example.org/example-320w.jpg" alt="Example" loading="lazy">`
-	output := Sanitize("http://example.org/", input)
-
-	if output != expected {
-		t.Errorf(`Wrong output: %s`, output)
-	}
-}
-
 func TestSourceWithSrcsetAndMedia(t *testing.T) {
 	input := `<picture><source media="(min-width: 800px)" srcset="elva-800w.jpg"></picture>`
 	expected := `<picture><source media="(min-width: 800px)" srcset="http://example.org/elva-800w.jpg"></picture>`
